from reactpy import component, html

@component
def Title(title):
    return html.script(f'() => {{document.title = "{title}";}}')

@component
def Favicon(src):
    return html.script(f"""
        const existingLinks = document.querySelectorAll("link[rel='icon']");
        existingLinks.forEach(link => link.remove());

        const newLink = document.createElement("link");
        newLink.rel = 'icon';
        newLink.type = 'image/x-icon';
        newLink.href = "{src}";
        document.head.appendChild(newLink);
    """)


@component
def Meta(meta_tags):
    return html.script(f"""
        const metaTags = {meta_tags};
        metaTags.forEach(meta => {{
            const metaElement = document.createElement("meta");
            Object.keys(meta).forEach(key => {{
                metaElement.setAttribute(key, meta[key]);
            }});
            document.head.appendChild(metaElement);
        }});
    """)


from setuptools import setup

setup(
    name='lilliepy-head',
    version='1.0',
    packages=['lilliepy_head'],
    install_requires=[
        'reactpy'
    ],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    description='helps with head related stuff in the lilliepy framework',
    keywords=[
        "lilliepy", "lilliepy-head", "reactpy"
    ],
    url='https://github.com/websitedeb/lilliepy-head',
    author='Sarthak Ghoshal',
    author_email='sarthak22.ghoshal@gmail.com',
    license='MIT',
    python_requires='>=3.6',
)